#[repr(u8)]pub enum SelectAreasStatus {
Success = 0,
Unsupportedarea = 1,
Invalidinmode = 2,
Invalidset = 3,
}Variants
Success = 0
Attempting to operate in the areas identified by the entries of the NewAreas field is allowed and possible. The SelectedAreas attribute is set to the value of the NewAreas field.
Unsupportedarea = 1
The value of at least one of the entries of the NewAreas field doesn’t match any entries in the SupportedAreas attribute.
Invalidinmode = 2
The received request cannot be handled due to the current mode of the device.
Invalidset = 3
The set of values is invalid. For example, areas on different floors, that a robot knows it can’t reach on its own.
Implementations