SkipAreaStatus

Enum SkipAreaStatus 

#[repr(u8)]
pub enum SkipAreaStatus { Success = 0, Invalidarealist = 1, Invalidinmode = 2, Invalidskippedarea = 3, }

Variants



Success = 0

Skipping the area is allowed and possible, or the device was operating at the last available area and has stopped.



Invalidarealist = 1

The SelectedAreas attribute is empty.



Invalidinmode = 2

The received request cannot be handled due to the current mode of the device. For example, the CurrentArea attribute is null or the device is not operating.



Invalidskippedarea = 3

The SkippedArea field doesn’t match an entry in the SupportedAreas list.

Implementations

Source

impl SkipAreaStatus

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value