#[repr(u8)]pub enum OperationalStatus {
Pending = 0,
Operating = 1,
Skipped = 2,
Completed = 3,
}Variants
Pending = 0
The device has not yet started operating at the given area, or has not finished operating at that area but it is not currently operating at the area
Operating = 1
The device is currently operating at the given area
Skipped = 2
The device has skipped the given area, before or during operating at it, due to a SkipArea command, due an out of band command (e.g. from the vendor’s application), due to a vendor specific reason, such as a time limit used by the device, or due the device ending operating unsuccessfully
Completed = 3
The device has completed operating at the given area
Implementations